@@ -10,7 +10,7 @@ use MooX::Press::Keywords ();
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005';
+our $VERSION   = '0.006';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -914,7 +914,7 @@ Define a more complicated class:
     ...;
   }
 
-Note that if the C<class> keyword without a block, it does I<not> act like
+Note that for the C<class> keyword without a block, it does I<not> act like
 the C<package> keyword by changing the "ambient" package. It just defines a
 totally empty class with no methods or attributes.
 
@@ -1019,7 +1019,7 @@ instances of it. It's like a template for generating classes. Then
 
 Because there are never any instances of "MyApp::Species", it doesn't
 make sense to have a B<Species> type constraint. Instead there are
-B<SpeciesClass> and B<SpeciesInstance> classes.
+B<SpeciesClass> and B<SpeciesInstance> type constraints.
 
   use MyApp::Types -is;
   
@@ -1575,7 +1575,7 @@ method but another wrapper!)
 
 C<< $next >> and C<< $self >> are both shifted off C<< @_ >>.
 
-If you use the signature-free version then C<< $next >> and C << $self >>
+If you use the signature-free version then C<< $next >> and C<< $self >>
 are not shifted off C<< @_ >> for you, but the variables are still defined.
 
   around marry {
@@ -1782,7 +1782,7 @@ MooX::Pression exports C<rw>, C<ro>, C<rwp>, and C<lazy> constants
 which make your attribute specs a little cleaner looking.
 
 MooX::Pression exports C<blessed> from L<Scalar::Util> because that can
-be handy to habe, and C<confess> from L<Carp>. MooX::Pression's copy
+be handy to have, and C<confess> from L<Carp>. MooX::Pression's copy
 of C<confess> is super-powered and runs its arguments through C<sprintf>.
 
   before vote {
@@ -2043,9 +2043,6 @@ MooX::Pression:
 
 =head2 Future Directions
 
-I'd like to consider adding Package::Variant support if that isn't too
-tricky.
-
 Slurpy parameters for methods need to be integrated.
 
 Something like MooX::HandlesVia or Moose native traits would be good.
